@@ -1,13 +1,9 @@
 ( cd opt/kde/share/doc/HTML/da/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ark ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kab ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kab ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kdf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kdm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kpm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kpm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ktuberling ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/amor ; rm -rf common )
@@ -20,8 +16,8 @@
 ( cd opt/kde/share/doc/HTML/da/kdvi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kgeo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kgeo ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/klpq ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/klpq ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kmix ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kmix ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kodo ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kolf ; rm -rf common )
@@ -32,6 +28,8 @@
 ( cd opt/kde/share/doc/HTML/da/korn ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksim ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kalzium ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kalzium ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/katomic ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/katomic ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksysguard ; rm -rf common )
@@ -40,12 +38,16 @@
 ( cd opt/kde/share/doc/HTML/da/kbounce ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kbattleship ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kaboodle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kaboodle ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/khangman ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/khangman ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kfloppy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/khexedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/khexedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kpercentage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kpercentage ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcalc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdesu ; rm -rf common )
@@ -86,8 +88,6 @@
 ( cd opt/kde/share/doc/HTML/da/klipper ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/klprfax ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/klprfax ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/konsole ; rm -rf common )
@@ -120,14 +120,14 @@
 ( cd opt/kde/share/doc/HTML/da/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kljettool ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kljettool ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kioslave ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kxconfig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kxconfig ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf qpl-license.html )
@@ -154,16 +154,28 @@
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf 9.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/9.png 9.png )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf headerbg.png )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf gpl-license.html )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf mainheader.html )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf grad.png )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf doxygen.css )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf web-doctop.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-default.css )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf kmenu.png )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf footer.html )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop1.png )
@@ -172,6 +184,8 @@
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf docheadergears.png )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop1a.png )
@@ -182,10 +196,14 @@
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf lgpl-license )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf mainfooter.html )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf bottom1.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf bottom2.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf header.html )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/header.html header.html )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-localised.css.template )
@@ -196,8 +214,106 @@
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/smb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/spellchecking ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/bell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/arts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/keys ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/powerctrl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kalarmd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/cookies ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/filetypes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/desktop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/cache ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/clock ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/email ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/fonts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/icons ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/khtml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/filemanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/mouse ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/panel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/proxy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kmixcfg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/passwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/ebrowsing ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/background ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmaccess ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/colors ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/crypto ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/energy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmstyle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/netpref ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlaunch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmcss ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/laptop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmnotify ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmsmserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/screensaver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/windowmanagement ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kwindecoration ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmkonsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/language ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/useragent ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/helpindex ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatcrit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatwarn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/keyboard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmtaskbar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kthememgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmfontinst ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/konq-plugins ; rm -rf common )
@@ -212,26 +328,22 @@
 ( cd opt/kde/share/doc/HTML/da/kasteroids ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/keduca ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kfract ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kfract ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kicker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/klatin ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/klatin ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/klines ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmines ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kmplot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kmplot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpaint ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpoker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kscore ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kscore ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kruler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kruler ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksnake ; rm -rf common )
@@ -284,6 +396,42 @@
 ( cd opt/kde/share/doc/HTML/da/ksokoban ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kteatime ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/pci ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/usb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/nics ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/interrupts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/blockdevices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/xserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/samba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/sound ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/partitions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/pcmcia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/processor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/ioports ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/konqueror ; rm -rf common )
